package com.plexworlds.l3.config

import com.intellij.openapi.options.SearchableConfigurable
import com.plexworlds.l3.llm.model.Models
import com.plexworlds.l3.llm.provider.Providers
import javax.swing.JComponent
import org.slf4j.Logger
import org.slf4j.LoggerFactory


class L3Config : SearchableConfigurable {

    private var panel: L3SettingsPanel? = null
    private val logger: Logger = LoggerFactory.getLogger(L3Config::class.java)


    override fun createComponent(): JComponent {
        val panel = L3SettingsPanel().also { this.panel = it }
        return panel.mainPanel
    }

    override fun isModified(): Boolean {
        val panel = this.panel ?: return false
        val l3PersistentState = L3PersistentState.getInstance()
        val isProviderModified = panel.providerComboBox.selectedItem != l3PersistentState.provider
        val isModelModified = panel.modelComboBox.selectedItem != l3PersistentState.model;
        val isModelOverrideModified = panel.modelOverrideField.text != l3PersistentState.modelOverride;
        val isUrlModified = panel.urlField.text != l3PersistentState.url
        return isProviderModified || isModelModified || isUrlModified || isModelOverrideModified
    }

    override fun reset() {
        val panel = this.panel ?: return
        val l3PersistentState = L3PersistentState.getInstance()
        panel.providerComboBox.selectedItem = l3PersistentState.provider
        panel.modelComboBox.selectedItem = l3PersistentState.model
        panel.modelOverrideField.text = l3PersistentState.modelOverride
        panel.urlField.text = l3PersistentState.url
    }

    override fun apply() {
        val panel = this.panel ?: return
        val l3PersistentState = L3PersistentState.getInstance()

        l3PersistentState.url = panel.urlField.text

        l3PersistentState.provider = Providers
            .valueOf(panel.providerComboBox.selectedItem as String).provider


        if (panel.modelOverrideField.text.isNotEmpty()) {
            l3PersistentState.modelOverride = panel.modelOverrideField.text
            l3PersistentState.model = Models
                .valueOf(panel.modelOverrideField.text).model
        } else {
            l3PersistentState.model = Models
                .valueOf(panel.modelComboBox.selectedItem as String).model
        }

    }

    override fun disposeUIResources() {
        this.panel = null
    }

    override fun getDisplayName() = "Local Llama Link"
    override fun getId() = "com.plexworlds.l3.config.L3Config"
}
