package com.plexworlds.l3.llm.provider

import com.plexworlds.l3.llm.model.Model
import io.github.ollama4j.OllamaAPI
import io.github.ollama4j.utils.Options
import io.github.ollama4j.utils.OptionsBuilder
import java.net.http.HttpTimeoutException

object Ollama : Provider {



    override fun call(
        host: String,
        model: Model,
        prefix: String,
        suffix: String
    ): String {
        if (!isPingOk(host)) {
            return "<No connection to Ollama API>"
        }

        for (i in 0..<RETRY_COUNT) {
            val suggestion = try {
                OllamaAPI(host).apply {
                    setRequestTimeoutSeconds(4)
                }.generate(
                    model.name(),
                    "${model.prefix()} $prefix ${model.suffix()}$suffix ${model.middle()}",
                    true,
                    options
                ).response.let {
                    if (it.endsWith(END)) it.substring(0, it.length - END.length).trim(' ', '\t', '\n') else it
                }
            } catch (e: HttpTimeoutException) {
                continue
            }
            if (suggestion.isNotBlank()) {
                return suggestion
            }
        }

        return "<Ollama API timeout>"
    }




    private val options: Options by lazy {
        OptionsBuilder()
            .setTemperature(0.4f)
            .build()
    }


    private fun isPingOk(host: String): Boolean {
        return try {
                OllamaAPI(host).ping()
            } catch (e: Exception) {
                false
            }
        }



    private const val END = "<EOT>"

    private const val RETRY_COUNT = 4
}
